/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "expression_trigonometric.h"

namespace mongo {

// The parse methods of the expressions are registered here in the .cpp file to prevent multiple
// definition errors.

/**
 * Inclusive Bounds
 */
REGISTER_STABLE_EXPRESSION(acos, ExpressionArcCosine::parse);
REGISTER_STABLE_EXPRESSION(asin, ExpressionArcSine::parse);
REGISTER_STABLE_EXPRESSION(atanh, ExpressionHyperbolicArcTangent::parse);
REGISTER_STABLE_EXPRESSION(acosh, ExpressionHyperbolicArcCosine::parse);

/**
 * Exclusive Bounds
 */
REGISTER_STABLE_EXPRESSION(cos, ExpressionCosine::parse);
REGISTER_STABLE_EXPRESSION(sin, ExpressionSine::parse);
REGISTER_STABLE_EXPRESSION(tan, ExpressionTangent::parse);

/**
 * Unbounded
 */
REGISTER_STABLE_EXPRESSION(atan, ExpressionArcTangent::parse);
REGISTER_STABLE_EXPRESSION(asinh, ExpressionHyperbolicArcSine::parse);
REGISTER_STABLE_EXPRESSION(cosh, ExpressionHyperbolicCosine::parse);
REGISTER_STABLE_EXPRESSION(sinh, ExpressionHyperbolicSine::parse);
REGISTER_STABLE_EXPRESSION(tanh, ExpressionHyperbolicTangent::parse);

REGISTER_STABLE_EXPRESSION(atan2, ExpressionArcTangent2::parse);

REGISTER_STABLE_EXPRESSION(degreesToRadians, ExpressionDegreesToRadians::parse);
REGISTER_STABLE_EXPRESSION(radiansToDegrees, ExpressionRadiansToDegrees::parse);
}  // namespace mongo
